import netCDF4
import inspect
import datetime

def get_date_utc(infile,t):

    nc = netCDF4.Dataset(infile,'r')
    unixtime = nc.variables["TIME"][t]
    nc.close()

    dd = datetime.datetime.fromtimestamp(int(unixtime),datetime.timezone.utc)
    hoge = '%04d-%02d-%02d_%02d:%02d:%02d' % (dd.year,dd.month,dd.day,dd.hour,\
           dd.minute,dd.second)

    return hoge + " UTC"

def get_date_jst(infile,t):

    nc = netCDF4.Dataset(infile,'r')
    unixtime = nc.variables["TIME"][t]
    nc.close()

    dd = datetime.datetime.fromtimestamp(int(unixtime))
    hoge = '%04d-%02d-%02d_%02d:%02d:%02d' % (dd.year,dd.month,dd.day,dd.hour,\
           dd.minute,dd.second)

    return hoge + " JST"


def get_missing_value(infile,varname):
    nc = netCDF4.Dataset(infile,'r')

    if not varname in nc.variables:
        print ("not found ", varname)
        exit(1)

    missing = nc.variables[varname].missing_value
    nc.close()

    return missing

def get_unitname(infile,varname):
    nc = netCDF4.Dataset(infile,'r')

    if not varname in nc.variables:
        print ("not found ", varname)
        exit(1)

    unitname = nc.variables[varname].units
    nc.close()

    return unitname



def check_NC_type(infile,varname):
    nc = netCDF4.Dataset(infile,'r')
    
    if not varname in nc.variables:
        print ("not found ", varname)
        exit(1)
        
    dim = nc.variables[varname].dimensions
    nc.close()

    dim_check = [0,0,0,0]
    if "TIME" in dim:
        dim_check[0] = 1
    else:
        dim_check[0] = 0

    if "LEV" in dim or "ALT" in dim:
        dim_check[1] = 1
    else:
        dim_check[1] = 0

    if "LAT" in dim:
        dim_check[2] = 1
    else:
        dim_check[2] = 0

    if "LON" in dim:
        dim_check[3] = 1
    else:
        dim_check[3] = 0

    return dim_check

def read_NC_T2D(infile,varname,t=-1):

    nc = netCDF4.Dataset(infile,'r')
    
    if not varname in nc.variables:
        print ("not found ", varname)
        exit(1)

    if t!= -1:
        DATA = nc.variables[varname][t][:][:]
    else:
        DATA = nc.variables[varname][:][:][:]

    nc.close()
    return DATA

def read_NC_T3D(infile,varname,t,k=-1):

    nc = netCDF4.Dataset(infile,'r')
    
    if not varname in nc.variables:
        print ("not found ", varname)
        exit(1)

    if k!=-1:
        DATA = nc.variables[varname][t][k][:][:]
    else:
        DATA = nc.variables[varname][t][:][:][:]

    nc.close()
    return DATA

def read_NC_2D(infile,varname):

    nc = netCDF4.Dataset(infile,'r')
    
    if not varname in nc.variables:
        print ("not found ", varname)
        exit(1)

    DATA2D = nc.variables[varname][:][:]

    nc.close()
    return DATA2D

def read_NC_1D(infile,varname):

    nc = netCDF4.Dataset(infile,'r')
    
    if not varname in nc.variables:
        print ("not found ", varname)
        exit(1)

    DATA1D = nc.variables[varname][:]

    nc.close()
    return DATA1D

def read_NC(infile, varname,t=-1,k=-1):

    type = check_NC_type(infile,varname)
    ndim = sum(type)

    if type   == [1,0,1,1] :

        print (varname,":2D evolution -> 2D snapshot")
        DATA = read_NC_T2D(infile,varname,t)

    elif type == [1,1,1,1] :

        if(k!=-1):
            print (varname,":3D evolution -> 2D snapshot")
            DATA = read_NC_T3D(infile,varname,t,k)
        else:
            print (varname,":3D evolution -> 3D snapshot")
            DATA = read_NC_T3D(infile,varname,t)

    elif type == [0,1,1,1] :

        if(k!=-1):
            print (varname,":3D static -> 2D snapshot")
            DATA = read_NC_T2D(infile,varname,k)
        else:
            print (varname,":3D static -> 3D snapshot")
            DATA = read_NC_T2D(infile,varname)

    elif type == [0,0,1,1] :
        print (varname,":2D static")
        DATA = read_NC_2D(infile,varname)
    elif ndim == 1:
        print (varname,":1dimensional")
        DATA = read_NC_1D(infile,varname)
    return DATA

